==> hubzero-cms-1.2.1_1.2.1.1.orig.tar.gz: hubzero-cms-1.2.1-1.2.1.1/cms/plugins/resources/about/views/index/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$sef = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->model->resource->id);

// Set the display date
switch ($this->model->params->get('show_date'))
{
	case 0: $thedate = ''; break;
	case 1: $thedate = $this->model->resource->created;    break;
	case 2: $thedate = $this->model->resource->modified;   break;
	case 3: $thedate = $this->model->resource->publish_up; break;
}

$this->model->resource->introtext = stripslashes($this->model->resource->introtext);
$this->model->resource->fulltxt = stripslashes($this->model->resource->fulltxt);
$this->model->resource->fulltxt = ($this->model->resource->fulltxt) ? trim($this->model->resource->fulltxt) : trim($this->model->resource->introtext);

// Parse for <nb:field> tags
$type = new ResourcesType($this->database);
$type->load($this->model->resource->type);

$data = array();
preg_match_all("#<nb:(.*?)>(.*?)</nb:(.*?)>#s", $this->model->resource->fulltxt, $matches, PREG_SET_ORDER);
if (count($matches) > 0) 
{
	foreach ($matches as $match)
	{
		$data[$match[1]] = $match[2];
	}
}
$this->model->resource->fulltxt = preg_replace("#<nb:(.*?)>(.*?)</nb:(.*?)>#s", '', $this->model->resource->fulltxt);
$this->model->resource->fulltxt = trim($this->model->resource->fulltxt);

include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'models' . DS . 'elements.php');
$elements = new ResourcesElements($data, $this->model->type->customFields);
$schema = $elements->getSchema();

// Set the document description
if ($this->model->resource->introtext) 
{
	$document = JFactory::getDocument();
	$document->setDescription(ResourcesHtml::encode_html(strip_tags($this->model->resource->introtext)));
}

// Check if there's anything left in the fulltxt after removing custom fields
// If not, set it to the introtext
$maintext = $this->model->resource->fulltxt;
$maintext = preg_replace('/&(?!(?i:\#((x([\dA-F]){1,5})|(104857[0-5]|10485[0-6]\d|1048[0-4]\d\d|104[0-7]\d{3}|10[0-3]\d{4}|0?\d{1,6}))|([A-Za-z\d.]{2,31}));)/i',"&amp;",$maintext);
$maintext = str_replace('<blink>', '', $maintext);
$maintext = str_replace('</blink>', '', $maintext);
?>
<div class="subject abouttab">
	<div class="resource">
<?php if ($thedate) { ?>
		<div class="grid">
		<div class="col span-half">
<?php } ?>
			<h4><?php echo JText::_('Category'); ?></h4>
			<p class="resource-content">
				<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&type=' . $this->model->type->alias); ?>">
					<?php echo $this->escape(stripslashes($this->model->type->type)); ?>
				</a>
			</p>
<?php if ($thedate) { ?>
		</div>
		<div class="col span-half omega">
			<h4><?php echo JText::_('Published on'); ?></h4>
			<p class="resource-content">
				<time datetime="<?php echo $thedate; ?>"><?php echo JHTML::_('date', $thedate, JText::_('DATE_FORMAT_HZ1')); ?></time>
			</p>
		</div>
		</div>
<?php } ?>
<?php
// Check how much we can display
if (!$this->model->access('view-all')) {
	// Protected - only show the introtext
?>
		<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_ABSTRACT'); ?></h4>
		<div class="resource-content">
			<?php echo $this->escape($this->model->resource->introtext); ?>
		</div>
<?php
} else {
	if (trim($maintext)) {
?>
		<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_ABSTRACT'); ?></h4>
		<div class="resource-content">
			<?php echo $maintext; ?>
		</div>
<?php
	}

	$citations = '';
	foreach ($schema->fields as $field)
	{
		if (isset($data[$field->name])) {
			if ($field->name == 'citations') {
				$citations = $data[$field->name];
			} else if ($value = $elements->display($field->type, $data[$field->name])) {
?>
			<h4><?php echo $field->label; ?></h4>
			<div class="resource-content">
				<?php echo $value; ?>
			</div>
<?php
			}
		}
	}

	if ($this->model->params->get('show_citation')) {
		if ($this->model->params->get('show_citation') == 1 || $this->model->params->get('show_citation') == 2) {
			// Citation instructions
			//$this->helper->getUnlinkedContributors();

			// Build our citation object
			$juri = JURI::getInstance();
			
			$cite = new stdClass();
			$cite->title = $this->model->resource->title;
			$cite->year = JHTML::_('date', $thedate, 'Y');
			$cite->location = $juri->base() . ltrim($sef, DS);
			$cite->date = JFactory::getDate()->toSql();
			$cite->url = '';
			$cite->type = '';
			$authors = array();
			$contributors = $this->model->contributors('!submitter');
			if ($contributors)
			{
				foreach ($contributors as $contributor)
				{
					$authors[] = $contributor->name ? $contributor->name : $contributor->xname;
				}
			}
			$cite->author = implode(';', $authors); //$this->helper->ul_contributors;
			
			if ($this->model->params->get('show_citation') == 2) {
				$citations = '';
			}
		} else {
			$cite = null;
		}

		$citeinstruct  = ResourcesHtml::citation($this->option, $cite, $this->model->resource->id, $citations, $this->model->resource->type, 0);
		$citeinstruct .= ResourcesHtml::citationCOins($cite, $this->model); //->resource, $this->model->params, $this->helper);
?>
			<h4><a name="citethis"></a><?php echo JText::_('PLG_RESOURCES_ABOUT_CITE_THIS'); ?></h4>
			<div class="resource-content">
				<?php echo $citeinstruct; ?>
			</div>
<?php
	}
}
// If the resource had a specific event date/time
if ($this->model->attribs->get('timeof', '')) {
	if (substr($this->model->attribs->get('timeof', ''), -8, 8) == '00:00:00') {
		$exp = JText::_('DATE_FORMAT_HZ1'); //'%B %d %Y';
	} else {
		$exp = JText::_('TIME_FORMAT_HZ1') . ', ' . JText::_('DATE_FORMAT_HZ1'); //'%I:%M %p, %B %d %Y';
	}
	if (substr($this->model->attribs->get('timeof', ''), 4, 1) == '-') {
		$seminarTime = ($this->model->attribs->get('timeof', '') != '0000-00-00 00:00:00' || $this->model->attribs->get('timeof', '') != '')
					  ? JHTML::_('date', $this->model->attribs->get('timeof', ''), $exp)
					  : '';
	} else {
		$seminarTime = $this->model->attribs->get('timeof', '');
	}
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_TIME'); ?></h4>
			<p class="resource-content"><time><?php echo $this->escape($seminarTime); ?></time></p>
<?php
}
// If the resource had a specific location
if ($this->model->attribs->get('location', '')) {
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_LOCATION'); ?></h4>
			<p class="resource-content"><?php echo $this->escape($this->model->attribs->get('location', '')); ?></p>
<?php
}

	if ($this->model->contributors('submitter')) {
	?>
			<h4><?php echo JText::_('Submitter'); ?></h4>
			<div class="resource-content">
				<span id="submitterlist">
					<?php 
					$view = new JView(array(
						'base_path' => JPATH_ROOT . DS . 'components' . DS . 'com_resources',
						'name'   => 'view',
						'layout' => '_submitters',
					));
					$view->option = $this->option;
					$view->contributors = $this->model->contributors('submitter');
					$view->badges = $this->plugin->get('badges', 0);
					$view->showorgs = 1;
					$view->display();
					?>
				</span>
			</div>
	<?php
	}

// Tags
if ($this->model->params->get('show_assocs')) {
	$tags = $this->model->tags();
	//$tagCloud = $this->helper->getTagCloud($this->authorized);
	if ($tags) {
		$tagger = new ResourcesTags($this->database);
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_TAGS'); ?></h4>
			<div class="resource-content">
				<?php echo $tagger->buildCloud($tags); ?>
			</div>
<?php
	}
}
?>
	</div><!-- / .resource -->
</div><!-- / .subject -->
<div class="clear"></div>

==> hubzero-cms-1.2_1.2.6.orig.tar.gz: hubzero-cms-1.2-1.2.6/cms/plugins/resources/about/views/index/tmpl/default.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

$sef = JRoute::_('index.php?option=' . $this->option . '&id=' . $this->model->resource->id);

// Set the display date
switch ($this->model->params->get('show_date'))
{
	case 0: $thedate = ''; break;
	case 1: $thedate = $this->model->resource->created;    break;
	case 2: $thedate = $this->model->resource->modified;   break;
	case 3: $thedate = $this->model->resource->publish_up; break;
}

$dateFormat = '%d %b %Y';
$yearFormat = '%Y';
$timeFormat = '%I:%M %p';
$tz = 0;
if (version_compare(JVERSION, '1.6', 'ge'))
{
	$dateFormat = 'd M Y';
	$yearFormat = 'Y';
	$timeFormat = 'h:M a';
	$tz = true;
}

$this->model->resource->introtext = stripslashes($this->model->resource->introtext);
$this->model->resource->fulltxt = stripslashes($this->model->resource->fulltxt);
$this->model->resource->fulltxt = ($this->model->resource->fulltxt) ? trim($this->model->resource->fulltxt) : trim($this->model->resource->introtext);

// Parse for <nb:field> tags
$type = new ResourcesType($this->database);
$type->load($this->model->resource->type);

$data = array();
preg_match_all("#<nb:(.*?)>(.*?)</nb:(.*?)>#s", $this->model->resource->fulltxt, $matches, PREG_SET_ORDER);
if (count($matches) > 0) 
{
	foreach ($matches as $match)
	{
		$data[$match[1]] = $match[2];
	}
}
$this->model->resource->fulltxt = preg_replace("#<nb:(.*?)>(.*?)</nb:(.*?)>#s", '', $this->model->resource->fulltxt);
$this->model->resource->fulltxt = trim($this->model->resource->fulltxt);

include_once(JPATH_ROOT . DS . 'components' . DS . 'com_resources' . DS . 'models' . DS . 'elements.php');
$elements = new ResourcesElements($data, $this->model->type->customFields);
$schema = $elements->getSchema();

// Set the document description
if ($this->model->resource->introtext) 
{
	$document =& JFactory::getDocument();
	$document->setDescription(ResourcesHtml::encode_html(strip_tags($this->model->resource->introtext)));
}

// Check if there's anything left in the fulltxt after removing custom fields
// If not, set it to the introtext
$maintext = $this->model->resource->fulltxt;
$maintext = preg_replace('/&(?!(?i:\#((x([\dA-F]){1,5})|(104857[0-5]|10485[0-6]\d|1048[0-4]\d\d|104[0-7]\d{3}|10[0-3]\d{4}|0?\d{1,6}))|([A-Za-z\d.]{2,31}));)/i',"&amp;",$maintext);
$maintext = str_replace('<blink>', '', $maintext);
$maintext = str_replace('</blink>', '', $maintext);
?>
<div class="subject abouttab">
	<div class="resource">
<?php if ($thedate) { ?>
		<div class="two columns first">
<?php } ?>
			<h4><?php echo JText::_('Category'); ?></h4>
			<p class="resource-content">
				<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&type=' . $this->model->type->alias); ?>">
					<?php echo $this->escape(stripslashes($this->model->type->type)); ?>
				</a>
			</p>
<?php if ($thedate) { ?>
		</div>
		<div class="two columns second">
			<h4><?php echo JText::_('Published on'); ?></h4>
			<p class="resource-content">
				<time datetime="<?php echo $thedate; ?>"><?php echo JHTML::_('date', $thedate, $dateFormat, $tz); ?></time>
			</p>
		</div>
		<div class="clearfix"></div>
<?php } ?>
<?php
// Check how much we can display
if (!$this->model->access('view-all')) {
	// Protected - only show the introtext
?>
		<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_ABSTRACT'); ?></h4>
		<div class="resource-content">
			<?php echo $this->escape($this->model->resource->introtext); ?>
		</div>
<?php
} else {
	if (trim($maintext)) {
?>
		<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_ABSTRACT'); ?></h4>
		<div class="resource-content">
			<?php echo $maintext; ?>
		</div>
<?php
	}

	if ($this->model->contributors('submitter')) {
?>
			<h4><?php echo JText::_('Submitter'); ?></h4>
			<div class="resource-content">
				<span id="submitterlist">
					<?php 
					$view = new JView(array(
						'base_path' => JPATH_ROOT . DS . 'components' . DS . 'com_resources',
						'name'   => 'view',
						'layout' => '_submitters',
					));
					$view->option = $this->option;
					$view->contributors = $this->model->contributors('submitter');
					$view->badges = $this->plugin->get('badges', 0);
					$view->showorgs = 1;
					$view->display();
					?>
				</span>
			</div>
<?php
	}
	$citations = '';
	foreach ($schema->fields as $field)
	{
		if (isset($data[$field->name])) {
			if ($field->name == 'citations') {
				$citations = $data[$field->name];
			} else if ($value = $elements->display($field->type, $data[$field->name])) {
?>
			<h4><?php echo $field->label; ?></h4>
			<div class="resource-content">
				<?php echo $value; ?>
			</div>
<?php
			}
		}
	}

	if ($this->model->params->get('show_citation')) {
		if ($this->model->params->get('show_citation') == 1 || $this->model->params->get('show_citation') == 2) {
			// Citation instructions
			//$this->helper->getUnlinkedContributors();

			// Build our citation object
			$juri =& JURI::getInstance();
			
			$cite = new stdClass();
			$cite->title = $this->model->resource->title;
			$cite->year = JHTML::_('date', $thedate, $yearFormat, $tz);
			$cite->location = $juri->base() . ltrim($sef, DS);
			$cite->date = date("Y-m-d H:i:s");
			$cite->url = '';
			$cite->type = '';
			$authors = array();
			$contributors = $this->model->contributors('!submitter');
			if ($contributors)
			{
				foreach ($contributors as $contributor)
				{
					$authors[] = $contributor->name;
				}
			}
			$cite->author = implode(';', $authors); //$this->helper->ul_contributors;
			
			if ($this->model->params->get('show_citation') == 2) {
				$citations = '';
			}
		} else {
			$cite = null;
		}

		$citeinstruct  = ResourcesHtml::citation($this->option, $cite, $this->model->resource->id, $citations, $this->model->resource->type, 0);
		$citeinstruct .= ResourcesHtml::citationCOins($cite, $this->model); //->resource, $this->model->params, $this->helper);
?>
			<h4><a name="citethis"></a><?php echo JText::_('PLG_RESOURCES_ABOUT_CITE_THIS'); ?></h4>
			<div class="resource-content">
				<?php echo $citeinstruct; ?>
			</div>
<?php
	}
}
// If the resource had a specific event date/time
if ($this->model->attribs->get('timeof', '')) {
	if (substr($this->model->attribs->get('timeof', ''), -8, 8) == '00:00:00') {
		$exp = $dateFormat; //'%B %d %Y';
	} else {
		$exp = $timeFormat . ', ' . $dateFormat; //'%I:%M %p, %B %d %Y';
	}
	if (substr($this->model->attribs->get('timeof', ''), 4, 1) == '-') {
		$seminarTime = ($this->model->attribs->get('timeof', '') != '0000-00-00 00:00:00' || $this->model->attribs->get('timeof', '') != '')
					  ? JHTML::_('date', $this->model->attribs->get('timeof', ''), $exp)
					  : '';
	} else {
		$seminarTime = $this->model->attribs->get('timeof', '');
	}
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_TIME'); ?></h4>
			<p class="resource-content"><time><?php echo $this->escape($seminarTime); ?></time></p>
<?php
}
// If the resource had a specific location
if ($this->model->attribs->get('location', '')) {
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_LOCATION'); ?></h4>
			<p class="resource-content"><?php echo $this->escape($this->model->attribs->get('location', '')); ?></p>
<?php
}
// Tags
if ($this->model->params->get('show_assocs')) {
	$tags = $this->model->tags();
	//$tagCloud = $this->helper->getTagCloud($this->authorized);
	if ($tags) {
		$tagger = new ResourcesTags($this->database);
?>
			<h4><?php echo JText::_('PLG_RESOURCES_ABOUT_TAGS'); ?></h4>
			<div class="resource-content">
				<?php echo $tagger->buildCloud($tags); ?>
			</div>
<?php
	}
}
?>
	</div><!-- / .resource -->
</div><!-- / .subject -->
<div class="clear"></div>
